import { LocaleConfig, PluginFunction } from '@vuepress/core';

interface BaseOptions {
    /**
     * 激活状态图标
     *
     * Activation status icon
     *
     * @default "/favicon.ico"
     */
    showIcon?: string;
    /**
     * 激活状态文字
     *
     * Activation status text
     *
     * @default "(*^▽^*)欢迎回来！"
     */
    showText?: string;
    /**
     * 隐藏状态图标
     *
     * Hide status icon
     *
     * @default "/favicon.ico"
     */
    hideIcon?: string;
    /**
     * 隐藏状态文字
     *
     * Hide status text
     *
     * @default "(ಥ﹏ಥ)不要离开我嘛~！"
     */
    hideText?: string;
    /**
     * 恢复时间
     *
     * Recover time
     *
     * @default 2000
     */
    recoverTime?: number;
}
interface BaseLocale {
    /**
     * 激活状态文字
     *
     * Activation status text
     *
     */
    showText: string;
    /**
     * 隐藏状态文字
     *
     * Hide status text
     *
     */
    hideText: string;
}

declare type DynamicTitleLocaleData = BaseLocale;
interface DynamicTitlePluginOptions extends BaseOptions {
    /**
     * Locale config for dynamic title
     */
    locales?: LocaleConfig<DynamicTitleLocaleData>;
}

/** DynamicTitle Plugin */
declare const DynamicTitlePlugin: (options?: DynamicTitlePluginOptions) => PluginFunction;

export { DynamicTitlePlugin as default };
